ChatroomEventListener class
Constructors
- ChatroomEventListener(void onEventResultChanged(RoomEventsType type, ChatError? error)?)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onEventResultChanged → void Function(RoomEventsType type, ChatError? error)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited