RoomEventsType enum
All business service errors
Values
- join → const RoomEventsType
- leave → const RoomEventsType
- destroyed → const RoomEventsType
- kick → const RoomEventsType
- mute → const RoomEventsType
- unmute → const RoomEventsType
- translate → const RoomEventsType
- recall → const RoomEventsType
- report → const RoomEventsType
- fetchParticipants → const RoomEventsType
- fetchMutes → const RoomEventsType
- sendMessage → const RoomEventsType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RoomEventsType> - A constant List of the values in this enum, in order of their declaration.